@@ -27,20 +27,12 @@ const SearchPopover = imports.searchPopover;
 
 const _PLACE_ICON_SIZE = 20;
 
-const Mode = {
-    IDLE: 0, // Nothing going on
-    ACTIVATED: 1, // Just activated, ignore changes to text
-    COMPLETION: 2, // We are doing completion against placeStore
-    RESULT: 3 // We are displaying results
-};
-
 var PlacePopover = GObject.registerClass({
     Signals : {
         'selected' : { param_types: [ GObject.TYPE_OBJECT ] }
     },
     Template: 'resource:///org/gnome/Maps/ui/place-popover.ui',
-    InternalChildren: [ 'hintRevealer',
-                        'scrolledWindow',
+    InternalChildren: [ 'scrolledWindow',
                         'stack',
                         'spinner',
                         'list',
@@ -58,25 +50,12 @@ var PlacePopover = GObject.registerClass({
         super._init(props);
 
         this._entry = this.relative_to;
-        this._entry.connect('notify::place', () => this._mode = Mode.ACTIVATED);
-
-        Application.routingDelegator.graphHopper.route.connect('update', () => {
-            this._mode = Mode.ACTIVATED;
-        });
 
         this._list.connect('row-activated', (list, row) => {
             if (row)
                 this.emit('selected', row.place);
         });
 
-        // Make sure we clear all selected rows when the search string change
-        this._entry.connect('changed', () => this._list.unselect_all());
-
-        // Do not show 'press enter to search' when we have
-        // selected rows in completion mode.
-        this._list.connect('selected-rows-changed',
-                           this._updateHint.bind(this));
-
         this._list.set_header_func((row, before) => {
             let header = new Gtk.Separator();
             if (before)
@@ -96,15 +75,12 @@ var PlacePopover = GObject.registerClass({
     showSpinner() {
         this._spinner.start();
         this._stack.visible_child = this._spinner;
-        this._updateHint();
 
         if (!this.visible)
             this.show();
     }
 
     showResult() {
-        this._mode = Mode.RESULT;
-
         if (this._spinner.active)
             this._spinner.stop();
 
@@ -119,52 +95,34 @@ var PlacePopover = GObject.registerClass({
     }
 
     showNoResult() {
-        this._mode = Mode.IDLE;
-
         if (this._spinner.active)
             this._spinner.stop();
 
         this._stack.visible_child = this._noResultsLabel;
     }
 
-    showCompletion() {
-        if (this._mode === undefined || this._mode === Mode.ACTIVATED) {
-            this._mode = Mode.IDLE;
-            return;
-        }
-
-        this._mode = Mode.COMPLETION;
-        this._stack.visible_child = this._scrolledWindow;
-        this._updateHint();
-
-        if (!this.visible)
-            this.show();
-    }
-
-    vfunc_hide() {
-        this._hintRevealer.reveal_child = false;
-        super.vfunc_hide();
-    }
-
     updateResult(places, searchString) {
-        this._list.forall((row) => row.destroy());
+        let i = 0;
 
-        places.forEach((place) => {
-            if (!place.location)
-                return;
+        places.forEach((p) => {
+            let row = this._list.get_row_at_index(i);
 
-            this._addRow(place, null, searchString);
+            // update existing row, if there is one, otherwise create new
+            if (row)
+                row.update(p.place, p.type, searchString);
+            else
+                this._addRow(p.place, p.type, searchString);
+
+            i++;
         });
-    }
 
-    updateCompletion(filter, searchString) {
-        this._list.forall((row) => row.destroy());
+        // remove remaining rows
+        let row = this._list.get_row_at_index(i);
 
-        filter.foreach((model, path, iter) => {
-            let place = model.get_value(iter, PlaceStore.Columns.PLACE);
-            let type = model.get_value(iter, PlaceStore.Columns.TYPE);
-            this._addRow(place, type, searchString);
-        });
+        while (row) {
+            row.destroy();
+            row = this._list.get_row_at_index(i);
+        }
     }
 
     _addRow(place, type, searchString) {
@@ -175,16 +133,4 @@ var PlacePopover = GObject.registerClass({
                                                   can_focus: true });
         this._list.add(row);
     }
-
-    _updateHint() {
-        if (this._stack.visible_child === this._spinner) {
-            this._hintRevealer.reveal_child = false;
-            return;
-        }
-
-        if (this._list.get_selected_rows().length > 0)
-            this._hintRevealer.reveal_child = false;
-        else
-            this._hintRevealer.reveal_child = true;
-    }
 });
