@@ -130,6 +130,29 @@ var Plan = GObject.registerClass({
         this.emit('update');
     }
 
+    /**
+     * Update plan with new itineraries, setting the new itineraries if it's
+     * the first fetch for a query, or extending the existing ones if it's
+     * a request to load more
+     */
+    updateWithNewItineraries(itineraries, arriveBy, extendPrevious) {
+        /* sort itineraries, by departure time ascending if querying
+         * by leaving time, by arrival time descending when querying
+         * by arriving time
+         */
+        if (arriveBy)
+            itineraries.sort(sortItinerariesByArrivalDesc);
+        else
+            itineraries.sort(sortItinerariesByDepartureAsc);
+
+        let newItineraries =
+            extendPrevious ? this.itineraries.concat(itineraries) : itineraries;
+
+        this.update(newItineraries);
+    }
+
+
+
     reset() {
         this._itineraries = [];
         this.bbox = null;
@@ -384,6 +407,10 @@ class Itinerary extends GObject.Object {
     get transitArrivalTimezoneOffset() {
         return this._getTransitArrivalLeg().timezoneOffset;
     }
+
+    get isWalkingOnly() {
+        return this.legs.length === 1 && !this.legs[0].isTransit;
+    }
 });
 
 var Leg = class Leg {
@@ -461,6 +488,10 @@ var Leg = class Leg {
         return this._route;
     }
 
+    set route(route) {
+        this._route = route;
+    }
+
     // try to get a shortened route name, suitable for overview rendering
     get compactRoute() {
         if (this._compactRoute)
@@ -500,6 +531,10 @@ var Leg = class Leg {
         return this._routeType;
     }
 
+    set routeType(routeType) {
+        this._routeType = routeType;
+    }
+
     get departure() {
         return this._departure;
     }
@@ -524,6 +559,10 @@ var Leg = class Leg {
         return this._polyline;
     }
 
+    set polyline(polyline) {
+        this._polyline = polyline;
+    }
+
     get fromCoordinate() {
         return this._fromCoordinate;
     }
@@ -560,6 +599,10 @@ var Leg = class Leg {
         return this._distance;
     }
 
+    set distance(distance) {
+        this._distance = distance;
+    }
+
     get duration() {
         return this._duration;
     }
@@ -584,10 +627,18 @@ var Leg = class Leg {
         return this._color || DEFAULT_ROUTE_COLOR;
     }
 
+    set color(color) {
+        this._color = color;
+    }
+
     get textColor() {
         return this._textColor || DEFAULT_ROUTE_TEXT_COLOR;
     }
 
+    set textColor(textColor) {
+        this._textColor = textColor;
+    }
+
     get tripShortName() {
         return this._tripShortName;
     }
@@ -761,9 +812,25 @@ var Stop = class Stop {
 };
 
 function sortItinerariesByDepartureAsc(first, second) {
-    return first.departure > second.departure;
+    /* always sort walk-only itineraries first, as they would always be
+     * starting at the earliest possible departure time
+     */
+    if (first.isWalkingOnly)
+        return -1;
+    else if (second.isWalkingOnly)
+        return 1;
+    else
+        return first.departure > second.departure;
 }
 
 function sortItinerariesByArrivalDesc(first, second) {
-    return first.arrival < second.arrival;
+    /* always sort walk-only itineraries first, as they would always be
+     * ending at the latest possible arrival time
+     */
+    if (first.isWalkingOnly)
+        return -1;
+    else if (second.isWalkingOnly)
+        return 1;
+    else
+        return first.arrival < second.arrival;
 }
