@@ -1209,7 +1209,7 @@ var OpenTripPlanner = class OpenTripPlanner {
                 let exit = step.exit;
 
                 if (exit)
-                    return _("In the roundaboat, take exit %s").format(exit);
+                    return _("In the roundabout, take exit %s").format(exit);
                 else if (street)
                     return _("In the roundabout, take exit to %s").format(street);
                 else
@@ -1230,7 +1230,7 @@ var OpenTripPlanner = class OpenTripPlanner {
                 if (street)
                     return _("Make a right u-turn onto %s").format(street);
                 else
-                    return _("Make a rigth u-turn");
+                    return _("Make a right u-turn");
             default:
                 return '';
         }
